"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBundleIdForIdentifierAsync = exports.getProfilesForBundleIdAsync = void 0;
const apple_utils_1 = require("@expo/apple-utils");
async function getProfilesForBundleIdDangerousAsync(context, bundleIdentifier) {
    const bundleId = await apple_utils_1.BundleId.findAsync(context, { identifier: bundleIdentifier });
    if (bundleId) {
        return bundleId.getProfilesAsync();
    }
    return [];
}
async function getProfilesForBundleIdAsync(context, bundleIdentifier) {
    const profiles = await getProfilesForBundleIdDangerousAsync(context, bundleIdentifier);
    // users sometimes have a poisoned Apple cache and receive stale data from the API
    // we call an arbitrary method, `getBundleIdAsync` on each profile
    // if it errors, the profile was stale, so we remove it
    const validProfileIds = new Set();
    await Promise.all(profiles.map(async (profile) => {
        try {
            await profile.getBundleIdAsync();
            validProfileIds.add(profile.id);
        }
        catch (e) {
            if (e.name === 'UnexpectedAppleResponse' &&
                e.message.includes('The specified resource does not exist - There is no resource of type')) {
                // TODO: add tracking analytics here
                return;
            }
            throw e;
        }
    }));
    return profiles.filter(profile => validProfileIds.has(profile.id));
}
exports.getProfilesForBundleIdAsync = getProfilesForBundleIdAsync;
async function getBundleIdForIdentifierAsync(context, bundleIdentifier) {
    const bundleId = await apple_utils_1.BundleId.findAsync(context, { identifier: bundleIdentifier });
    if (!bundleId) {
        throw new Error(`Failed to find Bundle ID item with identifier "${bundleIdentifier}"`);
    }
    return bundleId;
}
exports.getBundleIdForIdentifierAsync = getBundleIdForIdentifierAsync;
