/// <reference types="@expo/apple-utils/ts-declarations/expo__app-store" />
import { AgeRatingDeclaration, AppInfo, AppInfoLocalization, AppStoreReviewDetail, AppStoreVersion, AppStoreVersionLocalization, AppStoreVersionPhasedRelease } from '@expo/apple-utils';
import { AttributesOf } from '../../utils/asc';
import { AppleMetadata } from '../types';
/**
 * Serializes the Apple ASC entities into the metadata configuration schema.
 * This uses version 0 of the config schema.
 */
export declare class AppleConfigWriter {
    readonly schema: Partial<AppleMetadata>;
    constructor(schema?: Partial<AppleMetadata>);
    /** Get the schema result to write it to the config file */
    toSchema(): {
        configVersion: number;
        apple: Partial<AppleMetadata>;
    };
    setAgeRating(attributes: AttributesOf<AgeRatingDeclaration>): void;
    setInfoLocale(attributes: AttributesOf<AppInfoLocalization>): void;
    setCategories(attributes: Pick<AttributesOf<AppInfo>, 'primaryCategory' | 'primarySubcategoryOne' | 'primarySubcategoryTwo' | 'secondaryCategory' | 'secondarySubcategoryOne' | 'secondarySubcategoryTwo'>): void;
    setVersion(attributes: Omit<AttributesOf<AppStoreVersion>, 'releaseType' | 'earliestReleaseDate'>): void;
    setVersionReleaseType(attributes: Pick<AttributesOf<AppStoreVersion>, 'releaseType' | 'earliestReleaseDate'>): void;
    setVersionReleasePhased(attributes?: AttributesOf<AppStoreVersionPhasedRelease>): void;
    setVersionLocale(attributes: AttributesOf<AppStoreVersionLocalization>): void;
    setReviewDetails(attributes: AttributesOf<AppStoreReviewDetail>): void;
}
